==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggwidgetrendermodebutton.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggwidgetrendermodebutton.h"


#include "icontrolmodule.h"
#include "iimagefactory.h"
#include "imarkerviewobject.h"
#include "iobjecthelp.h"
#include "ishell.h"
#include "iviewmodule.h"

#include "iggwidgetkeyhandler.h"

#include "ibgwidgetbuttonsubject.h"

#include "iggsubjectfactory.h"
#include "iggparameter.h"
using namespace iggParameter;

//
//  Template
//
#include "iarraytemplate.h"


//
//  RenderMode button
//
iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *parent, bool registered) : iggWidget(parent->GetParent())
{
	mKeyHandler = parent;

	mDelayIcon = iImageFactory::FindIcon("delay.png");
	mReadyIcon = iImageFactory::FindIcon("ready.png");
	if(mDelayIcon==0 || mReadyIcon==0)
	{
		IERROR_REPORT_ERROR("Icon images are not found.");
	}
	if(registered) List().AddUnique(this);

	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,"",1);
	mSubject->SetFlat(true);
	mSubject->SetSize(16,16);

	//
	//  Since the subject belongs to something else, detach it
	//
	mSubjectOwner = false;

	this->SetBaloonHelp("Toggles the rendering mode between Delayed/Immediate. Press Shift+F1 for more help.","Widgets that require continuing interaction (such as sliders or line edits) support two modes: in the Delayed mode rendering of the visualization scene is performed only after the widget is released; in the Immediate mode every change of the widget state causes rendering of the scene. If the scene is complex and the rendering process is slow, the widget will feel \"jerky\" in the Immediate mode.");
}


iggWidgetRenderModeButton::~iggWidgetRenderModeButton()
{
	List().Remove(this);
}


bool iggWidgetRenderModeButton::UpdateWidgetBody()
{
	switch(mKeyHandler->GetRenderMode())
	{
	case _RenderModeDelayed:
		{
			if(mDelayIcon != 0) mSubject->SetIcon(*mDelayIcon);
			break;
		}
	case _RenderModeImmediate:
		{
			if(mReadyIcon != 0) mSubject->SetIcon(*mReadyIcon);
			break;
		}
	default:
		{
			IERROR_REPORT_ERROR("iggWidgetRenderModeButton should only be used with rendering widgets.");
		}
	}
	return true;
}


void iggWidgetRenderModeButton::OnVoid1Body()
{
	switch(mKeyHandler->GetRenderMode())
	{
	case _RenderModeDelayed:
		{
			mKeyHandler->SetRenderMode(_RenderModeImmediate);
			break;
		}
	case _RenderModeImmediate:
		{
			mKeyHandler->SetRenderMode(_RenderModeDelayed);
			break;
		}
	default:
		{
			IERROR_REPORT_ERROR("iggWidgetRenderModeButton should only be used with rendering widgets.");
		}
	}
	this->UpdateWidget();
}


void iggWidgetRenderModeButton::ResetToGlobal()
{
	mKeyHandler->SetRenderMode(_RenderModeUseGlobal);
	this->UpdateWidget();
}


void iggWidgetRenderModeButton::ResetAllToGlobal()
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->ResetToGlobal();
	}
}


void iggWidgetRenderModeButton::ShowAll(bool s)
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->Show(s);
	}
}


void iggWidgetRenderModeButton::UpdateAll()
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->UpdateWidget();
	}
}


iPointerArray<iggWidgetRenderModeButton>& iggWidgetRenderModeButton::List()
{
	static iPointerArray<iggWidgetRenderModeButton> list(100);
	return list;
}


void iggWidgetRenderModeButton::ClearLaidOutFlag(const ibgWidgetEntrySubject *e)
{
	if(e != 0) mWasLaidOut = true;
}


void iggWidgetRenderModeButton::ClearLaidOutFlag(const ibgWidgetTrackBallSubject *t)
{
	if(t != 0) mWasLaidOut = true;
}

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggwidgetrendermodebutton.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iggwidgetrendermodebutton.h"


#include "icontrolmodule.h"
#include "iimagefactory.h"
#include "imarker.h"
#include "iobjecthelp.h"
#include "ishell.h"
#include "iviewmodule.h"

#include "iggwidgetkeyhandler.h"

#include "ibgwidgetbuttonsubject.h"

#include "iggsubjectfactory.h"
#include "iggparameter.h"
using namespace iggParameter;

//
//  Template
//
#include "iarraytemplate.h"


//
//  RenderMode button
//
iggWidgetRenderModeButton::iggWidgetRenderModeButton(iggWidgetKeyHandlerBase *parent, bool registered) : iggWidget(parent->GetParent())
{
	mKeyHandler = parent;

	mDelayIcon = iImageFactory::FindIcon("delay.png");
	mReadyIcon = iImageFactory::FindIcon("ready.png");
	if(mDelayIcon==0 || mReadyIcon==0)
	{
		IERROR_REPORT("Icon images are not found.");
	}
	if(registered) List().AddUnique(this);

	mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToolButton,"",1);
	mSubject->SetFlat(true);
	mSubject->SetSize(16,16);

	//
	//  Since the subject belongs to something else, detach it
	//
	mSubjectOwner = false;

	this->SetBaloonHelp("Toggles the rendering mode between Delayed/Immediate. Press Shift+F1 for more help.","Widgets that require continuing interaction (such as sliders or line edits) support two modes: in the Delayed mode rendering of the visualization scene is performed only after the widget is released; in the Immediate mode every change of the widget state causes rendering of the scene. If the scene is complex and the rendering process is slow, the widget will feel \"jerky\" in the Immediate mode.");
}


iggWidgetRenderModeButton::~iggWidgetRenderModeButton()
{
	List().Remove(this);
}


void iggWidgetRenderModeButton::UpdateWidgetBody()
{
	switch(mKeyHandler->GetRenderMode())
	{
	case _RenderModeDelayed:
		{
			if(mDelayIcon != 0) mSubject->SetIcon(*mDelayIcon);
			break;
		}
	case _RenderModeImmediate:
		{
			if(mReadyIcon != 0) mSubject->SetIcon(*mReadyIcon);
			break;
		}
	default:
		{
			IERROR_REPORT("iggWidgetRenderModeButton should only be used with rendering widgets.");
		}
	}
}


void iggWidgetRenderModeButton::OnVoid1Body()
{
	switch(mKeyHandler->GetRenderMode())
	{
	case _RenderModeDelayed:
		{
			mKeyHandler->SetRenderMode(_RenderModeImmediate);
			break;
		}
	case _RenderModeImmediate:
		{
			mKeyHandler->SetRenderMode(_RenderModeDelayed);
			break;
		}
	default:
		{
			IERROR_REPORT("iggWidgetRenderModeButton should only be used with rendering widgets.");
		}
	}
	this->UpdateWidget();
}


void iggWidgetRenderModeButton::ResetToGlobal()
{
	mKeyHandler->SetRenderMode(_RenderModeUseGlobal);
	this->UpdateWidget();
}


void iggWidgetRenderModeButton::ResetAllToGlobal()
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->ResetToGlobal();
	}
}


void iggWidgetRenderModeButton::ShowAll(bool s)
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->Show(s);
	}
}


void iggWidgetRenderModeButton::UpdateAll()
{
	int i;
	iPointerArray<iggWidgetRenderModeButton> &list = List();

	for(i=0; i<list.Size(); i++)
	{
		list[i]->UpdateWidget();
	}
}


iPointerArray<iggWidgetRenderModeButton>& iggWidgetRenderModeButton::List()
{
	static iPointerArray<iggWidgetRenderModeButton> list(100);
	return list;
}


void iggWidgetRenderModeButton::ClearLaidOutFlag(const ibgWidgetEntrySubject *e)
{
	if(e != 0) mWasLaidOut = true;
}


void iggWidgetRenderModeButton::ClearLaidOutFlag(const ibgWidgetTrackBallSubject *t)
{
	if(t != 0) mWasLaidOut = true;
}
